Class: Canvas::Validator::FooterSchema
- Inherits:
-
MenuSchema
- Object
- MenuSchema
- Canvas::Validator::FooterSchema
- Defined in:
- lib/canvas/validators/footer_schema.rb
Overview
:documented: This class is used to validate a schema for a footer. For now the logic is exactly the same as the menu schema.
Example: { "max_item_levels" => 2, "supports_open_new_tab" => "true", "attributes" => { "text_color" => { "type" => "color" }, "background_color" => { "type" => "color" } }, "layout" => [ { "type" => "tab", "label" => "Content", "elements" => [ "text_color", "background_color" ] } ] }
Constant Summary
Constants inherited from MenuSchema
MenuSchema::ADDITIONAL_RESERVED_NAMES, MenuSchema::PERMITTED_KEYS
Instance Attribute Summary
Attributes inherited from MenuSchema
Method Summary
Methods inherited from MenuSchema
Constructor Details
This class inherits a constructor from Canvas::Validator::MenuSchema